==> patronum-1.19.1.tgz: package/throttle/index.js <==
import { createEffect, createEvent, createStore, guard, is, sample } from 'effector';
export function throttle(_ref) {
  var {
    source,
    timeout,
    target = createEvent({
      name: "target",
      sid: "r328r6"
    }, {
      name: "target",
      sid: "r328r6"
    })
  } = _ref;
  if (!is.unit(source)) throw new TypeError('source must be unit from effector');
  var $timeout = toStoreNumber(timeout);
  var timerFx = createEffect(timeout => new Promise(resolve => setTimeout(resolve, timeout)), {
    name: "timerFx",
    sid: "-pyjx8k"
  });

  // It's ok - nothing will ever start unless source is triggered
  var $payload = createStore(null, {
    and: {
      serialize: 'ignore'
    },
    name: "$payload",
    sid: "hinjft"
  }).on(source, (_, payload) => payload);
  var triggerTick = createEvent({
    name: "triggerTick",
    sid: "-sf8sou"
  });
  var $canTick = createStore(true, {
    and: {
      serialize: 'ignore'
    },
    name: "$canTick",
    sid: "-m0cqc"
  }).on(triggerTick, () => false).on(target, () => true);
  guard({
    and: [{
      clock: source,
      filter: $canTick,
      target: triggerTick
    }],
    or: {
      sid: "-hzhj9b"
    }
  });
  sample({
    and: [{
      source: $timeout,
      clock: triggerTick,
      target: timerFx
    }],
    or: {
      sid: "-hkn38k"
    }
  });
  sample({
    and: [{
      source: $payload,
      clock: timerFx.done,
      target
    }],
    or: {
      sid: "-hhcboe"
    }
  });
  return target;
}
function toStoreNumber(value) {
  if (is.store(value, {
    sid: "-h0ap6r"
  })) return value;
  if (typeof value === 'number') {
    if (value < 0 || !Number.isFinite(value)) throw new Error("timeout must be positive number or zero. Received: \"".concat(value, "\""));
    return createStore(value, {
      and: {
        name: '$timeout'
      },
      sid: "-h97n10"
    });
  }
  throw new TypeError("timeout parameter should be number or Store. \"".concat(typeof value, "\" was passed"));
}

==> patronum-1.20.0.tgz: package/throttle/index.js <==
import { createEffect, createEvent, createStore, guard, is, sample } from 'effector';
export function throttle(_ref) {
  var {
    source,
    timeout,
    target = createEvent({
      name: "target",
      sid: "r328r6"
    }, {
      name: "target",
      sid: "r328r6"
    })
  } = _ref;
  if (!is.unit(source)) throw new TypeError('source must be unit from effector');
  var $timeout = toStoreNumber(timeout);
  var timerFx = createEffect({
    name: "throttle(".concat(source.shortName || source.kind, ") effect"),
    handler: timeout => new Promise(resolve => setTimeout(resolve, timeout))
  }, {
    name: "timerFx",
    sid: "-pyjx8k"
  });

  // It's ok - nothing will ever start unless source is triggered
  var $payload = createStore(null, {
    and: {
      serialize: 'ignore'
    },
    name: "$payload",
    sid: "hzp5u0"
  }).on(source, (_, payload) => payload);
  var triggerTick = createEvent({
    name: "triggerTick",
    sid: "-ry76an"
  });
  var $canTick = createStore(true, {
    and: {
      serialize: 'ignore'
    },
    name: "$canTick",
    sid: "-4yqc5"
  }).on(triggerTick, () => false).on(target, () => true);
  guard({
    and: [{
      clock: source,
      filter: $canTick,
      target: triggerTick
    }],
    or: {
      sid: "-hyxqny"
    }
  });
  sample({
    and: [{
      source: $timeout,
      clock: triggerTick,
      target: timerFx
    }],
    or: {
      sid: "-hk3an7"
    }
  });
  sample({
    and: [{
      source: $payload,
      clock: timerFx.done,
      target
    }],
    or: {
      sid: "-hgsj31"
    }
  });
  return target;
}
function toStoreNumber(value) {
  if (is.store(value, {
    sid: "-gzqwle"
  })) return value;
  if (typeof value === 'number') {
    if (value < 0 || !Number.isFinite(value)) throw new Error("timeout must be positive number or zero. Received: \"".concat(value, "\""));
    return createStore(value, {
      and: {
        name: '$timeout'
      },
      sid: "-gs60mt"
    });
  }
  throw new TypeError("timeout parameter should be number or Store. \"".concat(typeof value, "\" was passed"));
}
